@@ -23,6 +23,8 @@ class ConfigBase(object):
     +-----------------------------------+--------------------------------------------+------------------------------+
     | __hide_fields__                   | Fields marked as hidden.                   | []                           |
     +-----------------------------------+--------------------------------------------+------------------------------+
+    | __add_fields__                    | Additional fields to add to the config.    | {}                           |
+    +-----------------------------------+--------------------------------------------+------------------------------+
     | __disable_fields__                | Field marked as disabled.                  | []                           |
     +-----------------------------------+--------------------------------------------+------------------------------+
     | __omit_fields__                   | Fields removed from the field list.        | []                           |
@@ -84,6 +86,7 @@ class ConfigBase(object):
         if self.__limit_fields__ is not None:
             fields.extend(self.__limit_fields__)
             fields.extend(self.__hide_fields__)
+            fields.extend(self.__add_fields__.keys())
             fields = self.__remove_duplicates(fields)
             return fields
         else:
