@@ -1,3 +1,4 @@
+from tw.dojo import DojoJsonRestStore
 from sprox.widgets.dojo import SproxEditableDojoGrid, SproxDojoGrid
 from sprox.tablebase import TableBase
 from sprox.metadata import FieldsMetadata
@@ -13,23 +14,33 @@ class DojoTableBase(TableBase):
 
     #object overrides
     __base_widget_type__ = SproxDojoGrid
-
+    __url__ = None
+    __column_options__ = {}
     def _do_get_widget_args(self):
         args = super(DojoTableBase, self)._do_get_widget_args()
+        if self.__url__ is not None:
+            args['action'] = self.__url__
         args['columns'] = self.__fields__
+        args['column_options'] = self.__column_options__
         args['headers'] = self.__headers__
         args['jsId'] = self.__sprox_id__
         return args
 
 """
-Experimental for next version.  Will not be included in 0.5
+Experimental for next version.  Will not be included in 0.5"""
 
 class DojoEditableTableBase(TableBase):
     __base_widget_type__ = SproxEditableDojoGrid
+    __url__ = None
+    __column_options__ = {}
 
     def _do_get_widget_args(self):
         args = super(DojoEditableTableBase, self)._do_get_widget_args()
+        if self.__url__ is not None:
+            args['action'] = self.__url__
         args['columns'] = self.__fields__
+        args['column_options'] = self.__column_options__
+        args['headers'] = self.__headers__
         args['jsId'] = self.__sprox_id__
         return args
-"""
\ No newline at end of file
+
