@@ -310,7 +310,7 @@ class EditableForm(FormBase):
 
     def _do_get_field_widgets(self, fields):
         widgets = super(EditableForm, self)._do_get_field_widgets(fields)
-        widgets['_method'] = SproxMethodPutHiddenField(id='_method')
+        widgets['_method'] = SproxMethodPutHiddenField(id='_method', validator=String(if_missing=None))
         return widgets
 
     __check_if_unique__ = False
