@@ -38,6 +38,7 @@ class SproxDojoGrid(DojoBase):
         super(SproxDojoGrid, self).update_params(d)
 
 class DojoJsonRestStoreInstance(JSSource):
+    engine_name='mako'
     require = ['twdojo.data.TWDojoRestStore']
     target='.json'
     url = '.json'
@@ -51,7 +52,7 @@ class DojoJsonRestStoreInstance(JSSource):
 
 class SproxEditableDojoGrid(DojoBase):
     engine_name=None
-    available_engines = ['mako','genshi']
+    available_engines = ['genshi', 'mako']
     css = [grid_css, tundragrid_css]
     require = ['dojox.grid.DataGrid', 'twdojo.data.TWDojoRestStore']
     dojoType = 'dojox.grid.DataGrid'
